# xcollection

| CI          | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![Code Coverage Status][codecov-badge]][codecov-link] |
| :---------- | :-----------------------------------------------------------------------------------------------------------------: |
| **Docs**    |                                   [![Documentation Status][rtd-badge]][rtd-link]                                    |
| **Package** |                        [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link]                         |
| **License** |                                       [![License][license-badge]][repo-link]                                        |

xcollection extends [xarray's data model](https://xarray.pydata.org/en/stable/getting-started-guide/why-xarray.html) to be able to handle a dictionary of xarray Datasets.

See [documentation](https://xcollection.readthedocs.io/en/latest/) for more information.

## Installation

xcollection can be installed from PyPI with pip:

```bash
python -m pip install xcollection
```

It is also available from `conda-forge` for conda installations:

```bash
conda install -c conda-forge xcollection
```

[github-ci-badge]: https://img.shields.io/github/workflow/status/NCAR/xcollection/CI?label=CI&logo=github&style=for-the-badge
[github-ci-link]: https://github.com/NCAR/xcollection/actions?query=workflow%3ACI
[codecov-badge]: https://img.shields.io/codecov/c/github/NCAR/xcollection.svg?logo=codecov&style=for-the-badge
[codecov-link]: https://codecov.io/gh/NCAR/xcollection
[rtd-badge]: https://img.shields.io/readthedocs/xcollection/latest.svg?style=for-the-badge
[rtd-link]: https://xcollection.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/xcollection?logo=pypi&style=for-the-badge
[pypi-link]: https://pypi.org/project/xcollection
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/xcollection?logo=anaconda&style=for-the-badge
[conda-link]: https://anaconda.org/conda-forge/xcollection
[license-badge]: https://img.shields.io/github/license/NCAR/xcollection?style=for-the-badge
[repo-link]: https://github.com/NCAR/xcollection
